@@ -27,7 +27,6 @@
 #include <libxml/xmlmemory.h>
 #include <libxml/parser.h>
 #include <glib.h>
-#include <gtk/gtk.h>
 
 extern gboolean lifereaStarted;
 
@@ -55,11 +54,15 @@ extern gboolean lifereaStarted;
 #  define N_(String) (String)
 #endif
 
-/** Conversion function which should be applied to all read XML strings, 
-   to ensure proper UTF8. doc points to the xml document and its encoding and
-   string is a xmlChar pointer to the read string. The result gchar
-   string is returned, the original XML string is freed. */
-gchar * common_utf8_fix(xmlChar * string);
+/** 
+ * Conversion function which should be applied to all read XML strings, 
+ * to ensure proper UTF8. doc points to the xml document and its encoding and
+ * string is a xmlChar pointer to the read string. The result gchar
+ * string is returned, the original XML string is freed. 
+ *
+ * @param string	possibly invalid UTF-8 string
+ */
+gchar * common_utf8_fix(gchar * string);
 
 /**
  * Parses the given string as a number.
@@ -97,7 +100,7 @@ gchar * common_format_nice_date(time_t date);
  *
  * @returns timestamp
  */
-time_t 	parseISO8601Date(gchar *date);
+time_t	parseISO8601Date(gchar *date);
 
 /**
  * Parses a RFC822 format date. This FAILS if a timezone string is
@@ -106,7 +109,7 @@ time_t 	parseISO8601Date(gchar *date);
  *
  * @returns timestamp (GMT, no daylight savings time)
  */
-time_t 	parseRFC822Date(gchar *date);
+time_t	parseRFC822Date(gchar *date);
 
 /**
  * Creates a date string from the given timestamp.
@@ -143,34 +146,6 @@ const gchar *	common_get_cache_path(void);
  */
 gchar * common_create_cache_filename(const gchar *folder, const gchar *filename, const gchar *extension);
 
-/**
- * Returns explanation string for the given HTTP 4xx error code.
- *
- * @param httpstatus	HTTP error code between 401 and 410
- *
- * @returns explanation string
- */
-const gchar * common_http_error_to_str(gint httpstatus);
-
-/**
- * Returns explanation string for the given network error code.
- *
- * @param netstatus	network error status
- *
- * @returns explanation string
- */
-const gchar * common_netio_error_to_str(gint netstatus);
-
-/**
- * Encodes all non URI conformant characters in the passed
- * string to be included in a HTTP URI.
- *
- * @param string	string to be URI-escaped (will be freed)
- *
- * @returns new string that can be inserted into a HTTP URI
- */
-gchar * common_encode_uri_string(gchar *string);
-
 /**
  * Takes an URL and returns a new string containing the escaped URL.
  *
@@ -200,23 +175,6 @@ xmlChar * common_uri_unescape(const xmlChar *url);
  */
 xmlChar * common_build_url(const gchar *url, const gchar *baseURL);
 
-/**
- * Adds a directory to the list of pixmap directories
- * to be searched when using create_pixbuf()
- *
- * @param directory	directory path name
- */
-void	add_pixmap_directory (const gchar *directory);
-
-/**
- * Takes a filename and tries to load the image into a GdkPixbuf. 
- *
- * @param filename	the filename
- *
- * @returns a new pixbuf or NULL
- */
-GdkPixbuf*  create_pixbuf (const gchar *filename);
-
 /**
  * Analyzes the given string and returns the LTR/RTL
  * setting that should be used when displaying it in
@@ -254,4 +212,13 @@ gchar *common_strreplace(gchar *string, const gchar *delimiter, const gchar *rep
  */
 char * common_strcasestr(const char *phaystack, const char *pneedle);
 
+/**
+ * Get file modification timestamp
+ *
+ * @param *file		the file name
+ *
+ * @returns modification timestamp (or 0 if file doesn't exist)
+ */
+time_t common_get_mod_time(const gchar *file);
+
 #endif
