@@ -291,7 +291,7 @@ google_source_api_edit_tag (GoogleSourceActionPtr action, updateRequestPtr reque
 {
 	update_request_set_source (request, GOOGLE_READER_EDIT_TAG_URL); 
 
-	gchar* prefix = "feed" ; 
+	const gchar* prefix = "feed" ; 
 	gchar* s_escaped = g_uri_escape_string (action->feedUrl, NULL, TRUE);
 	gchar* a_escaped = NULL ;
 	gchar* i_escaped = g_uri_escape_string (action->guid, NULL, TRUE);
@@ -384,7 +384,7 @@ google_source_edit_token_cb (const struct updateResult * const result, gpointer
 	request = update_request_new ();
 	request->updateState = update_state_copy (gsource->root->subscription->updateState);
 	request->options = update_options_copy (gsource->root->subscription->updateOptions) ;
-	update_state_set_cookies (request->updateState, gsource->sid);
+	update_request_set_auth_value (request, gsource->authHeaderValue);
 
 	if (action->actionType == EDIT_ACTION_MARK_READ || 
 	    action->actionType == EDIT_ACTION_MARK_UNREAD || 
@@ -421,7 +421,7 @@ google_source_edit_process (GoogleSourcePtr gsource)
 	request->updateState = update_state_copy (gsource->root->subscription->updateState);
 	request->options = update_options_copy (gsource->root->subscription->updateOptions);
 	request->source = g_strdup (GOOGLE_READER_TOKEN_URL);
-	update_state_set_cookies (request->updateState, gsource->sid);
+	update_request_set_auth_value(request, gsource->authHeaderValue);
 
 	update_execute_request (gsource, request, google_source_edit_token_cb, 
 	                        g_strdup(gsource->root->id), 0);
@@ -576,7 +576,7 @@ void google_source_edit_remove_subscription (GoogleSourcePtr gsource, const gcha
 
 gboolean google_source_edit_is_in_queue (GoogleSourcePtr gsource, const gchar* guid) 
 {
-	/* this is inefficient, but works for the timebeing */
+	/* this is inefficient, but works for the time being */
 	GList *cur = gsource->actionQueue->head; 
 	for(; cur; cur = g_list_next (cur)) { 
 		GoogleSourceActionPtr action = cur->data; 
