@@ -1,7 +1,7 @@
 /**
- * @file node_source.c generic feed list provider implementation
+ * @file node_source.c  generic node source provider implementation
  * 
- * Copyright (C) 2005-2007 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2005-2009 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "fl_sources/node_source.h"
+
 #include <gmodule.h>
 #include <gtk/gtk.h>
 #include <string.h>
@@ -27,76 +29,93 @@
 #include "debug.h"
 #include "feedlist.h"
 #include "folder.h"
+#include "item_state.h"
 #include "node.h"
 #include "node_type.h"
-#include "ui/ui_dialog.h"
+#include "ui/liferea_dialog.h"
+#include "ui/ui_common.h"
 #include "ui/ui_node.h"
-#include "fl_sources/node_source.h"
-#include "notification/notif_plugin.h"
+#include "fl_sources/bloglines_source.h"
+#include "fl_sources/default_source.h"
+#include "fl_sources/dummy_source.h"
+#include "fl_sources/google_source.h"
+#include "fl_sources/opml_source.h"
+#include "notification/notification.h"
 
 static GSList	*nodeSourceTypes = NULL;
 
-static nodeSourceTypePtr node_source_type_find(gchar *typeStr, guint capabilities) {
+static nodeSourceTypePtr
+node_source_type_find (const gchar *typeStr, guint capabilities)
+{
 	GSList *iter = nodeSourceTypes;
 	
-	while(iter) {
+	while (iter) {
 		nodeSourceTypePtr type = (nodeSourceTypePtr)iter->data;
-		if(((NULL == typeStr) || !strcmp(type->id, typeStr)) &&
-		   ((0 == capabilities) || (type->capabilities & capabilities)))
+		if (((NULL == typeStr) || !strcmp(type->id, typeStr)) &&
+		    ((0 == capabilities) || (type->capabilities & capabilities)))
 			return type;
-		iter = g_slist_next(iter);
+		iter = g_slist_next (iter);
 	}
 	
-	g_warning("Could not find source type \"%s\"\n!", typeStr);
+	g_warning ("Could not find source type \"%s\"\n!", typeStr);
 	return NULL;
 }
 
-nodePtr node_source_setup_root(void) {
-	nodePtr	rootNode;
-	nodeSourceTypePtr type;
-	
-	debug_enter("node_source_setup_root");
-
-	type = node_source_type_find(NULL, NODE_SOURCE_CAPABILITY_IS_ROOT);
-	if(!type) 
-		g_error("No root capable node source found!");
-		
-	rootNode = node_new();
-	node_set_type(rootNode, root_get_node_type());
-	rootNode->title = g_strdup("root");
-	rootNode->source = g_new0(struct nodeSource, 1);
-	rootNode->source->root = rootNode;
-	rootNode->source->type = type;
-	type->source_import(rootNode);
-	
-	debug_exit("node_source_setup_root");
-	
-	return rootNode;
-}
-
-gboolean node_source_type_register(nodeSourceTypePtr type) {
-
+static gboolean
+node_source_type_register (nodeSourceTypePtr type)
+{
 	/* check feed list provider plugin version */
-	if(NODE_SOURCE_TYPE_API_VERSION != type->api_version) {
-		debug3(DEBUG_PLUGINS, "feed list source API version mismatch: \"%s\" has version %d should be %d", type->name, type->api_version, NODE_SOURCE_TYPE_API_VERSION);
+	if (NODE_SOURCE_TYPE_API_VERSION != type->api_version) {
+		debug3 (DEBUG_PLUGINS, "feed list source API version mismatch: \"%s\" has version %d should be %d", type->name, type->api_version, NODE_SOURCE_TYPE_API_VERSION);
 		return FALSE;
 	} 
 
 	/* check if all mandatory functions are provided */
-	if(!(type->source_type_init &&
-	     type->source_type_deinit)) {
-		debug1(DEBUG_PLUGINS, "mandatory functions missing: \"%s\"", type->name);
+	if (!(type->source_type_init &&
+	      type->source_type_deinit)) {
+		debug1 (DEBUG_PLUGINS, "mandatory functions missing: \"%s\"", type->name);
 		return FALSE;
 	}
 
 	/* allow the plugin to initialize */
-	type->source_type_init();
+	type->source_type_init ();
 
-	nodeSourceTypes = g_slist_append(nodeSourceTypes, type);
+	nodeSourceTypes = g_slist_append (nodeSourceTypes, type);
 	
 	return TRUE;
 }
 
+nodePtr
+node_source_setup_root (void)
+{
+	nodePtr	rootNode;
+	nodeSourceTypePtr type;
+	
+	debug_enter ("node_source_setup_root");
+	
+	/* we need to register all source types once before doing anything... */
+	node_source_type_register (default_source_get_type ());
+	node_source_type_register (dummy_source_get_type ());
+	node_source_type_register (opml_source_get_type ());
+	node_source_type_register (bloglines_source_get_type ());
+	node_source_type_register (google_source_get_type ());
+
+	type = node_source_type_find (NULL, NODE_SOURCE_CAPABILITY_IS_ROOT);
+	if (!type) 
+		g_error ("No root capable node source found!");
+		
+	rootNode = node_new (root_get_node_type());
+	rootNode->title = g_strdup ("root");
+	rootNode->source = g_new0 (struct nodeSource, 1);
+	rootNode->source->root = rootNode;
+	rootNode->source->type = type;
+	type->source_import (rootNode);
+
+	debug_exit ("node_source_setup_root");
+	
+	return rootNode;
+}
+
 static void
 node_source_import (nodePtr node, nodePtr parent, xmlNodePtr xml, gboolean trusted)
 {
@@ -112,8 +131,6 @@ node_source_import (nodePtr node, nodePtr parent, xmlNodePtr xml, gboolean trust
 	if (typeStr) {
 		debug2 (DEBUG_CACHE, "creating node source instance (type=%s,id=%s)", typeStr, node->id);
 
-		node_add_child (parent, node, -1);
-		
 		node->available = FALSE;
 
 		/* scan for matching node source and create new instance */
@@ -134,7 +151,7 @@ node_source_import (nodePtr node, nodePtr parent, xmlNodePtr xml, gboolean trust
 		node->source = NULL;
 		node_source_new (node, type);
 		node_set_subscription (node, subscription_import (xml, trusted));
-				
+	
 		type->source_import (node);	// FIXME: pass trusted flag?
 	} else {
 		g_warning ("No source type given for node \"%s\". Ignoring it.", node_get_title (node));
@@ -149,6 +166,10 @@ node_source_export (nodePtr node, xmlNodePtr xml, gboolean trusted)
 	debug_enter ("node_source_export");
 
 	debug2 (DEBUG_CACHE, "node source export for node %s, id=%s", node->title, NODE_SOURCE_TYPE (node)->id);
+	
+	/* If the node source type was loaded using the dummy node source
+	   type we need to restore the original node source type id from
+	   temporarily saved into node->data */
 	if (!strcmp (NODE_SOURCE_TYPE (node)->id, NODE_SOURCE_TYPE_DUMMY_ID))
 		xmlNewProp (xml, BAD_CAST"sourceType", BAD_CAST (node->data));
 	else
@@ -171,14 +192,23 @@ node_source_new (nodePtr node, nodeSourceTypePtr type)
 /* source instance creation dialog */
 
 static void
-on_node_source_type_selected (GtkDialog *dialog,
-                              gint response_id,
-			      gpointer user_data)
+on_node_source_type_selected (GtkTreeSelection *selection, gpointer user_data)
+{
+	GtkTreeIter	iter;
+	GtkTreeModel	*model;
+
+	if (gtk_tree_selection_get_selected (selection, &model, &iter))
+		gtk_widget_set_sensitive (GTK_WIDGET (user_data), TRUE);
+	else
+		gtk_widget_set_sensitive (GTK_WIDGET (user_data), FALSE);
+}
+
+static void
+on_node_source_type_response (GtkDialog *dialog, gint response_id, gpointer user_data)
 {
 	GtkTreeSelection	*selection;
 	GtkTreeModel		*model;
 	GtkTreeIter		iter;
-	nodePtr 		parent = (nodePtr) user_data;
 	nodeSourceTypePtr	type;
 	
 	if (response_id == GTK_RESPONSE_OK) {
@@ -186,21 +216,14 @@ on_node_source_type_selected (GtkDialog *dialog,
 		g_assert (NULL != selection);
 		gtk_tree_selection_get_selected (selection, &model, &iter);
 		gtk_tree_model_get (model, &iter, 1, &type, -1);
-		type->source_new (parent);
+		type->source_new ();
 	}
 	
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
-static void
-on_node_source_type_dialog_destroy (GtkDialog *dialog,
-                                    gpointer user_data) 
-{
-	g_object_unref (user_data);
-}
-
-void
-ui_node_source_type_dialog (nodePtr parent)
+static gboolean
+ui_node_source_type_dialog (void)
 {
 	GSList 			*iter = nodeSourceTypes;
 	GtkWidget 		*dialog, *treeview;
@@ -212,11 +235,11 @@ ui_node_source_type_dialog (nodePtr parent)
 
 	if (!nodeSourceTypes) {
 		ui_show_error_box (_("No feed list source types found!"));
-		return;
+		return FALSE;
 	}		
 
 	/* set up the dialog */
-	dialog = liferea_dialog_new (PACKAGE_DATA_DIR G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S "node_source.glade", "node_source_type_dialog");
+	dialog = liferea_dialog_new ("node_source.glade", "node_source_type_dialog");
 
 	treestore = gtk_tree_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
 	
@@ -250,8 +273,14 @@ ui_node_source_type_dialog (nodePtr parent)
 	                             GTK_SELECTION_SINGLE);
 
 	g_signal_connect (G_OBJECT (dialog), "response",
-			  G_CALLBACK (on_node_source_type_selected), 
-			  (gpointer)parent);
+			  G_CALLBACK (on_node_source_type_response), 
+			  NULL);
+	g_signal_connect (G_OBJECT (gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview))), "changed",
+	                  G_CALLBACK (on_node_source_type_selected),
+	                  liferea_dialog_lookup (dialog, "ok_button"));
+	               
+			  
+	return TRUE;
 }
 
 void
@@ -266,11 +295,75 @@ node_source_auto_update (nodePtr node)
 	NODE_SOURCE_TYPE (node)->source_auto_update (node);
 }
 
+nodePtr
+node_source_add_subscription (nodePtr node, subscriptionPtr subscription)
+{
+	if (NODE_SOURCE_TYPE (node)->add_subscription)
+		return NODE_SOURCE_TYPE (node)->add_subscription (node, subscription);
+	else
+		g_warning ("node_source_add_subscription(): called on node source type that doesn't implement me!");
+		
+	return NULL;
+}
+
+nodePtr
+node_source_add_folder (nodePtr node, const gchar *title)
+{
+	if (NODE_SOURCE_TYPE (node)->add_folder)
+		return NODE_SOURCE_TYPE (node)->add_folder (node, title);
+	else
+		g_warning ("node_source_add_folder(): called on node source type that doesn't implement me!");
+
+	return NULL;
+}
+
+void
+node_source_remove_node (nodePtr node, nodePtr child)
+{
+	g_assert (child != node);
+	g_assert (child != child->source->root);
+	
+	if (NODE_SOURCE_TYPE (node)->remove_node)
+		NODE_SOURCE_TYPE (node)->remove_node (node, child);
+	else
+		g_warning ("node_source_remove_node(): called on node source type that doesn't implement me!");
+}
+
+void
+node_source_item_mark_read (nodePtr node, itemPtr item, gboolean newState)
+{
+	/* Item read state changes are optional for node source
+	   implementations. If they are supported the implementation
+	   has to call item_read_state_changed(), otherwise we do
+	   call it here. */
+	   
+	if (NODE_SOURCE_TYPE (node)->item_mark_read)
+		NODE_SOURCE_TYPE (node)->item_mark_read (node, item, newState);
+	else
+		item_read_state_changed (item, newState);
+}
+
+void
+node_source_item_set_flag (nodePtr node, itemPtr item, gboolean newState)
+{
+	/* Item flag state changes are optional for node source
+	   implementations. If they are supported the implementation
+	   has to call item_flag_state_changed(), otherwise we do
+	   call it here. */
+	   
+	if (NODE_SOURCE_TYPE (node)->item_set_flag)
+		NODE_SOURCE_TYPE (node)->item_set_flag (node, item, newState);
+	else
+		item_flag_state_changed (item, newState);
+}
+
 /* implementation of the node type interface */
 
 static void
 node_source_remove (nodePtr node)
 {
+	g_assert (node == node->source->root);
+	
 	if (NULL != NODE_SOURCE_TYPE (node)->source_delete)
 		NODE_SOURCE_TYPE (node)->source_delete (node);
 		
@@ -284,13 +377,6 @@ node_source_save (nodePtr node)
 	node_foreach_child (node, node_save);
 }
 
-static void
-node_source_process_update_result (nodePtr node, const struct updateResult * const result, guint32 flags)
-{
-	// FIXME: stupid interface, needs clarification
-	g_warning("node_source_process_update_result: This should never happen!");
-}
-
 static void
 node_source_free (nodePtr node)
 {
@@ -312,22 +398,22 @@ node_source_get_node_type (void)
 		nodeType->id			= "source";
 		nodeType->icon			= icons[ICON_DEFAULT];
 		nodeType->capabilities		= NODE_CAPABILITY_SHOW_UNREAD_COUNT |
+						  NODE_CAPABILITY_SHOW_ITEM_FAVICONS |
 						  NODE_CAPABILITY_UPDATE_CHILDS |
-						  NODE_CAPABILITY_UPDATE;
+						  NODE_CAPABILITY_UPDATE |
+						  NODE_CAPABILITY_ADD_CHILDS |
+						  NODE_CAPABILITY_REMOVE_CHILDS;
 		nodeType->import		= node_source_import;
 		nodeType->export		= node_source_export;
 		nodeType->load			= folder_get_node_type()->load;
 		nodeType->save			= node_source_save;
 		nodeType->update_counters	= folder_get_node_type()->update_counters;
-		nodeType->process_update_result = node_source_process_update_result;
 		nodeType->remove		= node_source_remove;
 		nodeType->render		= node_default_render;
 		nodeType->request_add		= ui_node_source_type_dialog;
 		nodeType->request_properties	= ui_node_rename;
-		nodeType->process_update_result	= node_source_process_update_result;
 		nodeType->free			= node_source_free;
 	}
 
 	return nodeType; 
 }
-
