@@ -1,7 +1,7 @@
 /**
- * @file folder.c feed list callbacks for folders
+ * @file folder.c  sub folders for hierarchic node sources
  * 
- * Copyright (C) 2006-2007 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2006-2009 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
  */
 
 #include "common.h"
-#include "conf.h"
 #include "debug.h"
 #include "export.h"
 #include "feedlist.h"
@@ -27,59 +26,58 @@
 #include "itemset.h"
 #include "node.h"
 #include "vfolder.h"
+#include "ui/ui_common.h"
 #include "ui/ui_folder.h"
 #include "ui/ui_node.h"
 
-static void folder_merge_child_items(nodePtr node, gpointer user_data) {
+/* Note: The folder node type implements the behaviour of a folder like
+   node in the feed list. The two most important features are viewing the
+   unread items of all child feeds and displaying the aggregated unread count 
+   of all child feeds.
+   
+   The folder node type does not implement the hierarchy of the feed list! */
+
+static void
+folder_merge_child_items (nodePtr node, gpointer user_data)
+{
 	itemSetPtr	folderItemSet = (itemSetPtr)user_data;
 	itemSetPtr	nodeItemSet;
 
-	nodeItemSet = node_get_itemset(node);
-	folderItemSet->ids = g_list_concat(folderItemSet->ids, nodeItemSet->ids);
+	nodeItemSet = node_get_itemset (node);
+	folderItemSet->ids = g_list_concat (folderItemSet->ids, nodeItemSet->ids);
 	nodeItemSet->ids = NULL;
-	itemset_free(nodeItemSet);
+	itemset_free (nodeItemSet);
 }
 
-static itemSetPtr folder_load(nodePtr node) {
+static itemSetPtr
+folder_load (nodePtr node)
+{
 	itemSetPtr	itemSet;
 	
-	itemSet = g_new0(struct itemSet, 1);
+	itemSet = g_new0 (struct itemSet, 1);
 	itemSet->nodeId = node->id;
 
-	node_foreach_child_data(node, folder_merge_child_items, itemSet);
+	node_foreach_child_data (node, folder_merge_child_items, itemSet);
 	return itemSet;
 }
 
-static void folder_import(nodePtr node, nodePtr parent, xmlNodePtr cur, gboolean trusted) {
-	
-	node_set_data(node, NULL);
-	node_add_child(parent, node, -1);
-	
-	cur = cur->xmlChildrenNode;
-	while(cur) {
-		if(!xmlStrcmp(cur->name, BAD_CAST"outline"))
-			import_parse_outline(cur, node, node->source, trusted);
-		cur = cur->next;				
-	}
+static void
+folder_import (nodePtr node, nodePtr parent, xmlNodePtr cur, gboolean trusted)
+{	
+	/* Folders have no special properties to be imported. */	
 }
 
-static void folder_export(nodePtr node, xmlNodePtr cur, gboolean trusted) {
-	
-	if(trusted) {
-		if(ui_node_is_folder_expanded(node->id))
-			xmlNewProp(cur, BAD_CAST"expanded", BAD_CAST"true");
-		else
-			xmlNewProp(cur, BAD_CAST"collapsed", BAD_CAST"true");
-	}
-
-	debug1(DEBUG_CACHE, "adding folder: title=%s", node_get_title(node));
-	export_node_children(node, cur, trusted);	
+static void
+folder_export (nodePtr node, xmlNodePtr cur, gboolean trusted)
+{	
+	/* Folders have no special properties to be exported. */
 }
 
-static void folder_save(nodePtr node) {
-	
+static void
+folder_save (nodePtr node)
+{	
 	/* A folder has no own state but must give all childs the chance to save theirs */
-	node_foreach_child(node, node_save);
+	node_foreach_child (node, node_save);
 }
 
 static void
@@ -91,25 +89,25 @@ folder_add_child_unread_count (nodePtr node, gpointer user_data)
 		*unreadCount += node->unreadCount;
 }
 
-static void folder_update_unread_count(nodePtr node) {
-
+static void
+folder_update_unread_count(nodePtr node)
+{
 	node->unreadCount = 0;
-	node_foreach_child_data(node, folder_add_child_unread_count, &node->unreadCount);
+	node_foreach_child_data (node, folder_add_child_unread_count, &node->unreadCount);
 }
 
-static void folder_remove(nodePtr node) {
-
-	/* remove all children */
-	node_foreach_child(node, node_request_remove);
-	g_assert(!node->children);
-	
-	/* remove the folder */
-	ui_node_remove_node(node);
+static void
+folder_remove (nodePtr node)
+{
+	/* Ensure that there are no children anymore */
+	g_assert (!node->children);
 }
 
-nodeTypePtr folder_get_node_type(void) { 
-
+nodeTypePtr
+folder_get_node_type (void)
+{
 	static struct nodeType fnti = {
+		NODE_CAPABILITY_SHOW_ITEM_FAVICONS |
 		NODE_CAPABILITY_ADD_CHILDS |
 		NODE_CAPABILITY_REMOVE_CHILDS |
 		NODE_CAPABILITY_SUBFOLDERS |
@@ -123,7 +121,6 @@ nodeTypePtr folder_get_node_type(void) {
 		folder_load,
 		folder_save,
 		folder_update_unread_count,
-		NULL,			/* process_update_result */
 		folder_remove,
 		node_default_render,
 		ui_folder_add,
@@ -134,8 +131,9 @@ nodeTypePtr folder_get_node_type(void) {
 	return &fnti; 
 }
 
-nodeTypePtr root_get_node_type(void) { 
-
+nodeTypePtr
+root_get_node_type (void)
+{
 	/* the root node is identical to the folder type,
 	   just a different node type... */
 	static struct nodeType rnti = {
@@ -152,7 +150,6 @@ nodeTypePtr root_get_node_type(void) {
 		folder_load,
 		folder_save,
 		folder_update_unread_count,
-		NULL,		/* process_update_result() */
 		folder_remove,
 		node_default_render,
 		ui_folder_add,
