@@ -23,9 +23,10 @@
 
 typedef enum {
 	MIGRATION_MODE_INVALID = 0,
-	MIGRATION_MODE_10_TO_14,
-	MIGRATION_MODE_12_TO_14,
-	MIGRATION_MODE_13_TO_14
+	MIGRATION_FROM_10,
+	MIGRATION_FROM_12,
+	MIGRATION_FROM_13,
+	MIGRATION_FROM_14,
 } migrationMode;
 
 /**
