@@ -1,7 +1,7 @@
 /**
  * @file newsbin.c  news bin node type implementation
  * 
- * Copyright (C) 2006-2007 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2006-2009 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "newsbin.h"
+
 #include <gtk/gtk.h>
 
 #include "common.h"
@@ -25,13 +27,12 @@
 #include "feed.h"
 #include "feedlist.h"
 #include "itemlist.h"
-#include "newsbin.h"
+#include "metadata.h"
 #include "render.h"
 #include "vfolder.h"
-#include "ui/ui_dialog.h"
+#include "ui/liferea_dialog.h"
 #include "ui/ui_feedlist.h"
 #include "ui/ui_node.h"
-#include "ui/ui_popup.h"
 
 static GtkWidget *newnewsbindialog = NULL;
 static GSList * newsbin_list = NULL;
@@ -42,12 +43,6 @@ newsbin_get_list (void)
 	return newsbin_list;
 }
 
-static void
-newsbin_new(nodePtr node)
-{
-	feedlist_schedule_save();
-}
-
 static void
 newsbin_import (nodePtr node, nodePtr parent, xmlNodePtr cur, gboolean trusted)
 {
@@ -67,7 +62,6 @@ newsbin_remove (nodePtr node)
 {
 	newsbin_list = g_slist_remove(newsbin_list, node);
 	feed_get_node_type()->remove(node);
-	ui_popup_update_menues();
 }
 
 static gchar *
@@ -86,52 +80,48 @@ newsbin_render (nodePtr node)
 	return output;
 }
 
-static void
-ui_newsbin_add (nodePtr parent)
+static gboolean
+ui_newsbin_add (void)
 {
 	GtkWidget	*nameentry;
 	
 	if (!newnewsbindialog || !G_IS_OBJECT (newnewsbindialog))
 		newnewsbindialog = liferea_dialog_new (NULL, "newnewsbindialog");
 
-	nameentry = liferea_dialog_lookup(newnewsbindialog, "nameentry");
-	gtk_entry_set_text(GTK_ENTRY(nameentry), "");
-		
-	gtk_widget_show(newnewsbindialog);
+	nameentry = liferea_dialog_lookup (newnewsbindialog, "newsbinnameentry");
+	gtk_entry_set_text (GTK_ENTRY (nameentry), "");
+
+	gtk_window_present (GTK_WINDOW (newnewsbindialog));
+	
+	return TRUE;
 }
 
 void 
 on_newnewsbinbtn_clicked (GtkButton *button, gpointer user_data)
 {
 	nodePtr		newsbin;
-	int		pos;
 	
-	newsbin = node_new();
-	node_set_title(newsbin, (gchar *)gtk_entry_get_text(GTK_ENTRY(liferea_dialog_lookup(newnewsbindialog, "nameentry"))));
-	node_set_type(newsbin, newsbin_get_node_type());
-	node_set_data(newsbin, (gpointer)feed_new());
-	newsbin_new(newsbin);
+	newsbin = node_new (newsbin_get_node_type ());
+	node_set_title (newsbin, (gchar *)gtk_entry_get_text (GTK_ENTRY (liferea_dialog_lookup (newnewsbindialog, "newsbinnameentry"))));
+	node_set_data (newsbin, (gpointer)feed_new ());
 
-	ui_feedlist_get_target_folder(&pos);
-	node_add_child(feedlist_get_insertion_point(), newsbin, pos);
-	feedlist_schedule_save();
-	ui_feedlist_select(newsbin);
-	
 	newsbin_list = g_slist_append(newsbin_list, newsbin);
-	ui_popup_update_menues();
+	
+	feedlist_node_added (newsbin);
 }
 
 void 
-on_popup_copy_to_newsbin (gpointer user_data, guint callback_action, GtkWidget *widget)
+on_popup_copy_to_newsbin (gpointer data)
 {
 	nodePtr		newsbin;
 	itemPtr		item, copy;
 
-	newsbin = g_slist_nth_data(newsbin_list, callback_action);
+	newsbin = g_slist_nth_data(newsbin_list, GPOINTER_TO_INT(data));
 	item = itemlist_get_selected();
 	if(item) {
 		copy = item_copy(item);
 		copy->nodeId = newsbin->id;	/* necessary to become independent of original item */
+		copy->parentNodeId = g_strdup (item->nodeId);
 		
 		/* To avoid item doubling in vfolders we reset
 		   simple vfolder match attributes */
@@ -140,10 +130,10 @@ on_popup_copy_to_newsbin (gpointer user_data, guint callback_action, GtkWidget *
 		
 		/* To provide a hint in the rendered output what the orginial 
 		   feed was the original website link/title are added */		
-		if(!copy->real_source_url)
-			copy->real_source_url = g_strdup(node_get_base_url(node_from_id(item->nodeId)));
-		if(!copy->real_source_title)
-			copy->real_source_title = g_strdup(node_get_title(node_from_id(item->nodeId)));
+		if(!metadata_list_get (copy->metadata, "realSourceUrl"))
+			metadata_list_set (&(copy->metadata), "realSourceUrl", node_get_base_url(node_from_id(item->nodeId)));
+		if(!metadata_list_get (copy->metadata, "realSourceTitle"))
+			metadata_list_set (&(copy->metadata), "realSourceTitle", node_get_title(node_from_id(item->nodeId)));
 		
 		/* do the same as in node_merge_item(s) */
 		db_item_update(copy);
