@@ -26,16 +26,9 @@
 #define _XOPEN_SOURCE	600 	/* glibc2 needs this (man strptime) */
 
 #include "ns_dc.h"
-#include "conf.h"
 #include "common.h"
 #include "metadata.h"
 
-#define TABLE_START	"<div class=\"feedfoottitle\">additional Dublin Core information</div><table class=\"addfoot\">"
-#define FIRSTTD		"<tr class=\"feedfoot\"><td class=\"feedfootname\"><span class=\"feedfootname\">"
-#define NEXTTD		"</span></td><td class=\"feedfootvalue\"><span class=\"feedfootvalue\">"
-#define LASTTD		"</span></td></tr>"
-#define TABLE_END	"</table>"
-
 #define TYPE_DIRECTORY	0
 #define TYPE_CHANNEL	1
 #define TYPE_FORMAT	2
@@ -89,123 +82,139 @@ or item view inside the header or footer of display.
 
 */
 
-static gchar * taglist[] = {	"title",
-				"creator",
-				"subject",
-				"description",
-				"publisher",
-				"contributor",				
-				"date",
-				"type",
-				"format",
-				"identifier",
-				"source",
-				"language",
-				"coverage",
-				"rights", 
-				NULL
-			   };
+static const gchar * taglist[] = {	"title",
+					"creator",
+					"subject",
+					"description",
+					"publisher",
+					"contributor",				
+					"date",
+					"type",
+					"format",
+					"identifier",
+					"source",
+					"language",
+					"coverage",
+					"rights", 
+					NULL
+				   };
 
 /* mapping of the tags specified by taglist to the backends channel
    structure taglist, NULL means no mapping but extra type that must
    be registered explicitly! */
-static gchar * mapToFeedMetadata[] = {
-			 	"feedTitle",		/* title */ 
-				"creator",		/* creator */
-				"category",		/* subject */
-				"description",		/* description */
-				"publisher",		/* publisher */
-				"contributor",		/* contributor */
-				NULL,			/* date (seldom used, e.g. slashdot) */
-				NULL,			/* type */
-				NULL,			/* format */
-				NULL,			/* identifier */
-				NULL,			/* source */
-				"language",		/* language */
-				NULL,			/* coverage */
-				"copyright"		/* rights */
-			  };
+static const gchar * mapToFeedMetadata[] = {
+				 	"feedTitle",		/* title */ 
+					"creator",		/* creator */
+					"category",		/* subject */
+					"description",		/* description */
+					"publisher",		/* publisher */
+					"contributor",		/* contributor */
+					NULL,			/* date (seldom used, e.g. slashdot) */
+					NULL,			/* type */
+					NULL,			/* format */
+					NULL,			/* identifier */
+					NULL,			/* source */
+					"language",		/* language */
+					NULL,			/* coverage */
+					"copyright"		/* rights */
+				  };
 
-static gchar * mapToItemMetadata[] = {
-			 	"itemTitle",		/* title */ 
-				"creator",		/* creator */
-				"category",		/* subject */
-				"description",		/* description */
-				"publisher",			/* publisher */
-				"contributor",		/* contributor */				
-				NULL,			/* date (won't be processed...) */
-				NULL,			/* type */
-				NULL,			/* format */
-				NULL,			/* identifier */
-				NULL,			/* source */
-				"language",		/* language */
-				NULL,			/* coverage */				
-				"copyright"		/* rights */
-			  };
+static const gchar * mapToItemMetadata[] = {
+				 	"itemTitle",		/* title */ 
+					"creator",		/* creator */
+					"category",		/* subject */
+					"description",		/* description */
+					"publisher",		/* publisher */
+					"contributor",		/* contributor */				
+					NULL,			/* date (won't be processed...) */
+					NULL,			/* type */
+					NULL,			/* format */
+					NULL,			/* identifier */
+					NULL,			/* source */
+					"language",		/* language */
+					NULL,			/* coverage */				
+					"copyright"		/* rights */
+				  };
 			  
 
 /* generic tag parsing (used for RSS and Atom) */
-static void parse_tag(feedParserCtxtPtr ctxt, xmlNodePtr cur, gboolean isFeedTag) {
+static void
+parse_tag (feedParserCtxtPtr ctxt, xmlNodePtr cur, gboolean isFeedTag)
+{
 	int 		i, j;
-	gchar		*date, *mapping, *value, *tmp;
+	gchar		*date, *value, *tmp;
+	const gchar	*mapping;
 	gboolean	isNotEmpty;
 	
 	/* special handling for the ISO 8601 date item tags */
-	if(!isFeedTag) {
-		if(!xmlStrcmp((const xmlChar *)"date", cur->name)) {
- 			if(date = common_utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1))) {
-				i = parseISO8601Date(date);
+	if (!isFeedTag) {
+		if (!xmlStrcmp (BAD_CAST "date", cur->name)) {
+ 			if (NULL != (date = common_utf8_fix ((gchar *)xmlNodeListGetString (cur->doc, cur->xmlChildrenNode, 1)))) {
+				i = parseISO8601Date (date);
 				ctxt->item->time = i;
-				g_free(date);
+				g_free (date);
 			}
 			return;
 		}
 	}
 
 	/* compare with each possible tag name */
-	for(i = 0; taglist[i] != NULL; i++) {
-		if(!xmlStrcmp((const xmlChar *)taglist[i], cur->name)) {
- 			value = common_utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
-	 		if(NULL != value) {
+	for (i = 0; taglist[i] != NULL; i++) {
+		if (!xmlStrcmp ((const xmlChar *)taglist[i], cur->name)) {
+ 			value = common_utf8_fix ((gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
+	 		if (value) {
 				/* check if value consist of whitespaces only */				
-				for(j = 0, tmp = value, isNotEmpty = FALSE; j < g_utf8_strlen(value, -1); j++) {
-					if(!g_unichar_isspace(*tmp)) {
+				for (j = 0, tmp = value, isNotEmpty = FALSE; j < g_utf8_strlen (value, -1); j++) {
+					if (!g_unichar_isspace (*tmp)) {
 						isNotEmpty = TRUE;
 						break;
 					}
-					tmp = g_utf8_next_char(tmp);
+					tmp = g_utf8_next_char (tmp);
 				}
 
-				if(isNotEmpty) {
-					if(isFeedTag) {
-						if(mapping = mapToFeedMetadata[i])
-							ctxt->subscription->metadata = metadata_list_append(ctxt->subscription->metadata, mapping, value);
+				if (isNotEmpty) {
+					if (isFeedTag) {
+						if (NULL != (mapping = mapToFeedMetadata[i]))
+							ctxt->subscription->metadata = metadata_list_append (ctxt->subscription->metadata, mapping, value);
 					} else {
-						if(mapping = mapToItemMetadata[i])
-							ctxt->item->metadata = metadata_list_append(ctxt->item->metadata, mapping, value);
+						if (NULL != (mapping = mapToItemMetadata[i]))
+							ctxt->item->metadata = metadata_list_append (ctxt->item->metadata, mapping, value);
 					}
 				} 
-				g_free(value);
+				g_free (value);
 			}			
 			return;
 		}
 	}
 }
 
-static void parse_channel_tag(feedParserCtxtPtr ctxt, xmlNodePtr cur)	{ parse_tag(ctxt, cur, TRUE); }
-static void parse_item_tag(feedParserCtxtPtr ctxt, xmlNodePtr cur)	{ parse_tag(ctxt, cur, FALSE); }
-
-static void ns_dc_register_ns(NsHandler *nsh, GHashTable *prefixhash, GHashTable *urihash) {
-	g_hash_table_insert(prefixhash, "dc", nsh);
-	g_hash_table_insert(urihash, "http://purl.org/dc/elements/1.1/", nsh);
-	g_hash_table_insert(urihash, "http://purl.org/dc/elements/1.0/", nsh);
+static void
+parse_channel_tag (feedParserCtxtPtr ctxt, xmlNodePtr cur)
+{
+	parse_tag(ctxt, cur, TRUE);
 }
 
-NsHandler *ns_dc_getRSSNsHandler(void) {
+static void
+parse_item_tag (feedParserCtxtPtr ctxt, xmlNodePtr cur)
+{
+	parse_tag(ctxt, cur, FALSE);
+}
+
+static void
+ns_dc_register_ns (NsHandler *nsh, GHashTable *prefixhash, GHashTable *urihash)
+{
+	g_hash_table_insert (prefixhash, "dc", nsh);
+	g_hash_table_insert (urihash, "http://purl.org/dc/elements/1.1/", nsh);
+	g_hash_table_insert (urihash, "http://purl.org/dc/elements/1.0/", nsh);
+}
+
+NsHandler *
+ns_dc_get_handler (void)
+{
 	NsHandler 	*nsh;
 	
-	nsh = g_new0(NsHandler, 1);
-	nsh->prefix			= g_strdup("dc");
+	nsh = g_new0 (NsHandler, 1);
+	nsh->prefix			= "dc";
 	nsh->registerNs			= ns_dc_register_ns;
 	nsh->parseChannelTag		= parse_channel_tag;
 	nsh->parseItemTag		= parse_item_tag;
