@@ -1,7 +1,7 @@
 /**
  * @file ns_slash.h slash namespace support
  *
- * Copyright (C) 2003-2006 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2003-2007 Lars Lindner <lars.lindner@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -24,6 +24,6 @@
 
 #include "metadata.h"
 
-NsHandler *ns_slash_getRSSNsHandler(void);
+NsHandler *ns_slash_get_handler(void);
 
 #endif
