@@ -24,6 +24,9 @@
 #include <libxml/tree.h>
 #include "feed.h"
 
+extern GHashTable *pie_nstable;
+extern GHashTable *ns_pie_ns_uri_table;
+
 feedHandlerPtr	pie_init_feed_handler(void);
 
 /**
@@ -34,4 +37,6 @@ feedHandlerPtr	pie_init_feed_handler(void);
  */
 gchar* pie_parse_content_construct(xmlNodePtr cur);
 
+gchar* parseAuthor(xmlNodePtr cur);
+
 #endif
