@@ -2,7 +2,7 @@
  * @file ui_prefs.c program preferences
  *
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
- * Copyright (C) 2004-2007 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2004-2009 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,27 +19,29 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "ui/ui_prefs.h"
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
 
 #include <stdlib.h>
 #include <string.h>
-#include <gtk/gtk.h>
 
 #include "common.h"
 #include "conf.h"
+#include "enclosure.h"
 #include "favicon.h"
 #include "feedlist.h"
 #include "itemlist.h"
 #include "social.h"
-#include "ui/ui_dialog.h"
-#include "ui/ui_enclosure.h"
+#include "ui/enclosure_list_view.h"
+#include "ui/liferea_dialog.h"
+#include "ui/liferea_shell.h"
+#include "ui/ui_common.h"
 #include "ui/ui_itemlist.h"
-#include "ui/ui_mainwindow.h"
-#include "ui/ui_prefs.h"
 #include "ui/ui_tray.h"
-#include "notification/notif_plugin.h"
+#include "notification/notification.h"
 
 /* file type tree store column ids */
 enum fts_columns {
@@ -50,7 +52,8 @@ enum fts_columns {
 };
 
 extern GSList *htmlviewPlugins;
-extern GSList *socialBookmarkSites;
+extern GSList *bookmarkSites;	/* from social.c */
+extern GSList *linkSearchSites;	/* from social.c */
 
 static GtkWidget *prefdialog = NULL;
 
@@ -58,9 +61,8 @@ static GtkWidget *prefdialog = NULL;
 static struct enclosureDownloadTool enclosure_download_commands[] = {
 	{ "wget -q -O %s %s", TRUE },
 	{ "curl -s -o %s %s", TRUE },
-	{ "dbus-send --session --dest=org.gnome.gwget.ApplicationService /org/gnome/gwget/Gwget org.gnome.gwget.Application.OpenURI string:%s uint32:0", FALSE },
+	{ "dbus-send --session --print-reply --dest=org.gnome.gwget.ApplicationService /org/gnome/gwget/Gwget org.gnome.gwget.Application.OpenURI string:%s uint32:0", FALSE },
 	{ "kget %s", FALSE },
-	NULL
 };
 
 /** order must match enclosure_download_commands[] */
@@ -71,55 +73,41 @@ static struct browser browsers[] = {
 		"gnome", N_("GNOME Default Browser"), "gnome-open %s", 
 		NULL, NULL,
 		NULL, NULL,
-		NULL, NULL,
-		FALSE
+		NULL, NULL
 	},
 	{
 		/* tested with SeaMonkey 1.0.6 */
 		"mozilla", "Mozilla", "mozilla %s",
 		NULL, "mozilla -remote openURL(%s)",
-		NULL, "mozillax -remote 'openURL(%s,new-window)'",
-		NULL, "mozilla -remote 'openURL(%s,new-tab)'",
-		FALSE
+		NULL, "mozilla -remote 'openURL(%s,new-window)'",
+		NULL, "mozilla -remote 'openURL(%s,new-tab)'"
 	},
 	{
 		/* tested with Firefox 1.5 and 2.0 */
 		"firefox", "Firefox","firefox \"%s\"",
 		NULL, "firefox -a firefox -remote \"openURL(%s)\"",
 		NULL, "firefox -a firefox -remote 'openURL(%s,new-window)'",
-		NULL, "firefox -a firefox -remote 'openURL(%s,new-tab)'",
-		TRUE
-	},
-	{
-		/* tested with Netscape 4.76 */
-		"netscape", "Netscape", "netscape \"%s\"",
-		NULL, "netscape -remote \"openURL(%s)\"",
-		NULL, "netscape -remote \"openURL(%s,new-window)\"",
-		NULL, NULL,
-		TRUE
+		NULL, "firefox -a firefox -remote 'openURL(%s,new-tab)'"
 	},
 	{
 		"opera", "Opera","opera \"%s\"",
 		"opera \"%s\"", "opera -remote \"openURL(%s)\"",
 		"opera -newwindow \"%s\"", NULL,
-		"opera -newpage \"%s\"", NULL,
-		FALSE
+		"opera -newpage \"%s\"", NULL
 	},
 	{
 		"epiphany", "Epiphany","epiphany \"%s\"",
 		NULL, NULL,
 		"epiphany \"%s\"", NULL,
-		"epiphany -n \"%s\"", NULL,
-		FALSE
+		"epiphany -n \"%s\"", NULL
 	},
 	{
 		"konqueror", "Konqueror", "kfmclient openURL \"%s\"",
 		NULL, NULL,
 		NULL, NULL,
-		NULL, NULL,
-		FALSE
+		NULL, NULL
 	},
-	{	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, FALSE }
+	{	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL }
 };
 
 /** GConf representation of toolbar styles */
@@ -141,6 +129,9 @@ static gchar * startup_update_options[] = {
 	NULL
 };
 
+/* Note: these update interval literal should be kept in sync with the 
+   ones in ui_subscription.c! */
+    
 static gchar * default_update_interval_unit_options[] = {
 	N_("minutes"),
 	N_("hours"),
@@ -266,6 +257,7 @@ on_trayiconoptionbtn_clicked (GtkButton *button, gpointer user_data)
 	conf_set_bool_value (SHOW_TRAY_ICON, enabled);
 	gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "newcountintraybtn"), enabled);
 	gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "minimizetotraybtn"), enabled);
+	gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "startintraybtn"), enabled);
 }
 
 void
@@ -276,7 +268,7 @@ on_popupwindowsoptionbtn_clicked (GtkButton *button, gpointer user_data)
 	notification_enable (conf_get_bool_value (SHOW_POPUP_WINDOWS));
 }
 
-void
+static void
 on_feed_startup_update_changed (gpointer user_data)
 {
 	conf_set_int_value (STARTUP_FEED_ACTION, gtk_combo_box_get_active (GTK_COMBO_BOX (liferea_dialog_lookup (prefdialog, "startupActionCombo"))));
@@ -323,15 +315,21 @@ on_disablejavascript_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 }
 
 void
-on_allowflash_toggled (GtkToggleButton *togglebutton, gpointer user_data)
+on_enableplugins_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 {
-	conf_set_bool_value (ALLOW_FLASH, gtk_toggle_button_get_active (togglebutton));
+	conf_set_bool_value (ENABLE_PLUGINS, gtk_toggle_button_get_active (togglebutton));
 }
 
-void
+static void
 on_socialsite_changed (GtkOptionMenu *optionmenu, gpointer user_data)
 {
-	social_set_site ((gchar *)user_data);
+	social_set_bookmark_site ((gchar *)user_data);
+}
+
+static void
+on_linksearchsite_changed (GtkOptionMenu *optionmenu, gpointer user_data)
+{
+	social_set_link_search_site ((gchar *)user_data);
 }
 
 static void
@@ -342,7 +340,7 @@ on_gui_toolbar_style_changed (gpointer user_data)
 	conf_set_str_value (TOOLBAR_STYLE, gui_toolbar_style_values[value]);
 
 	style = conf_get_toolbar_style ();
-	ui_mainwindow_set_toolbar_style (style);
+	liferea_shell_set_toolbar_style (style);
 	g_free (style);
 }
 
@@ -361,8 +359,8 @@ on_default_update_interval_value_changed (GtkSpinButton *spinbutton, gpointer us
 	gint		updateInterval, intervalUnit;
 	GtkWidget	*unitWidget, *valueWidget;
 
-	unitWidget = liferea_dialog_lookup (prefdialog, "refreshIntervalUnitComboBox");
-	valueWidget = liferea_dialog_lookup (prefdialog, "refreshIntervalSpinButton");
+	unitWidget = liferea_dialog_lookup (prefdialog, "globalRefreshIntervalUnitComboBox");
+	valueWidget = liferea_dialog_lookup (prefdialog, "globalRefreshIntervalSpinButton");
 	intervalUnit = gtk_combo_box_get_active (GTK_COMBO_BOX (unitWidget));
 	updateInterval = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (valueWidget));
 
@@ -380,38 +378,38 @@ on_default_update_interval_unit_changed (gpointer user_data)
 	on_default_update_interval_value_changed (NULL, NULL);
 }
 
-void on_menuselection_clicked(GtkButton *button, gpointer user_data) {
-	gint		active_button;
+/*
+void
+on_menuselection_clicked (GtkButton *button, gpointer user_data)
+{
+	gint active_button;
 	
-	active_button = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(button), "option_number"));
-	switch(active_button) {
+	active_button = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT(button), "option_number"));
+	switch (active_button) {
 		case 1:
-			conf_set_bool_value(DISABLE_MENUBAR, FALSE);
-			conf_set_bool_value(DISABLE_TOOLBAR, FALSE);
+			conf_set_bool_value (DISABLE_MENUBAR, FALSE);
+			conf_set_bool_value (DISABLE_TOOLBAR, FALSE);
 			break;
 		case 2:
-			conf_set_bool_value(DISABLE_MENUBAR, FALSE);
-			conf_set_bool_value(DISABLE_TOOLBAR, TRUE);
+			conf_set_bool_value (DISABLE_MENUBAR, FALSE);
+			conf_set_bool_value (DISABLE_TOOLBAR, TRUE);
 			break;
 		case 3:
-			conf_set_bool_value(DISABLE_MENUBAR, TRUE);
-			conf_set_bool_value(DISABLE_TOOLBAR, FALSE);
+			conf_set_bool_value (DISABLE_MENUBAR, TRUE);
+			conf_set_bool_value (DISABLE_TOOLBAR, FALSE);
 			break;
 		default:
 			break;
 	}
 	
-	ui_mainwindow_update_menubar();
-	ui_mainwindow_update_toolbar();
-}
+	liferea_shell_update_menubar ();
+	liferea_shell_update_toolbar ();
+}*/
 
 static void
 on_updateallfavicons_clicked (GtkButton *button, gpointer user_data)
 {
-	GTimeVal now;
-	
-	g_get_current_time (&now);
-	feedlist_foreach_data (node_update_favicon, &now);
+	feedlist_foreach (node_update_favicon);
 }
 
 static void
@@ -467,7 +465,7 @@ on_proxypasswordentry_changed (GtkEditable *editable, gpointer user_data)
 	conf_set_str_value (PROXY_PASSWD, gtk_editable_get_chars (editable,0,-1));
 }
 
-void
+static void
 on_skim_key_changed (gpointer user_data) 
 {
 	conf_set_int_value (BROWSE_KEY_SETTING, gtk_combo_box_get_active (GTK_COMBO_BOX (user_data)));
@@ -494,17 +492,19 @@ void on_enc_action_change_btn_clicked(GtkButton *button, gpointer user_data) {
 	}
 }
 
-void on_enc_action_remove_btn_clicked(GtkButton *button, gpointer user_data) {
+void
+on_enc_action_remove_btn_clicked (GtkButton *button, gpointer user_data)
+{
 	GtkTreeModel		*model;
 	GtkTreeSelection	*selection;
 	GtkTreeIter		iter;
 	gpointer		type;
 
-	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(liferea_dialog_lookup(prefdialog, "enc_action_view")));
-	if(gtk_tree_selection_get_selected(selection, &model, &iter)) {
-		gtk_tree_model_get(model, &iter, FTS_PTR, &type, -1);
-		gtk_tree_store_remove(GTK_TREE_STORE(model), &iter);
-		ui_enclosure_remove_type(type);
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (liferea_dialog_lookup (prefdialog, "enc_action_view")));
+	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+		gtk_tree_model_get (model, &iter, FTS_PTR, &type, -1);
+		gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
+		enclosure_mime_type_remove (type);
 	}
 }
 
@@ -546,53 +546,49 @@ void on_minimizetotraybtn_clicked(GtkButton *button, gpointer user_data) {
 	conf_set_bool_value(DONT_MINIMIZE_TO_TRAY, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)));
 }
 
+void
+on_startintraybtn_clicked (GtkButton *button, gpointer user_data)
+{
+	conf_set_bool_value (START_IN_TRAY, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)));
+}
+
+void
+on_useAvahiSync_toggled (GtkToggleButton *button, gpointer user_data)
+{
+	gboolean enabled = gtk_toggle_button_get_active (button);
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog, "avahiServiceNameEntry")), enabled);
+	gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog, "avahiServicePasswordEntry")), enabled);
+	conf_set_bool_value (SYNC_AVAHI_ENABLED, enabled);
+}
+
+void
+on_hidetoolbar_toggled (GtkToggleButton *button, gpointer user_data)
+{
+	conf_set_bool_value (DISABLE_TOOLBAR, gtk_toggle_button_get_active (button));
+	liferea_shell_update_toolbar ();
+}
+
 /*------------------------------------------------------------------------------*/
 /* preferences dialog callbacks 						*/
 /*------------------------------------------------------------------------------*/
 
-static void
-ui_prefs_setup_combo_menu (const gchar *widgetName,
-                           gchar **options,
-                           GCallback callback,
-                           gint defaultValue)
-{
-	GtkListStore	*listStore;
-	GtkTreeIter	treeiter;
-	GtkWidget	*widget;
-	guint		i;
-	
-	listStore = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
-	widget = liferea_dialog_lookup (prefdialog, widgetName);
-	g_assert (NULL != widget);
-	for (i = 0; options[i] != NULL; i++) {
-		gtk_list_store_append (listStore, &treeiter);
-		gtk_list_store_set (listStore, &treeiter, 0, _(options[i]), 1, i, -1);
-	}
-	gtk_combo_box_set_model (GTK_COMBO_BOX (widget), GTK_TREE_MODEL (listStore));
-	if (-1 <= defaultValue)
-		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), defaultValue);
-		
-	g_signal_connect (G_OBJECT (widget), "changed", callback, widget);
-}
-
 static void ui_pref_destroyed_cb(GtkWidget *widget, void *data) {
 
 	prefdialog = NULL;
 }
 
-void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
-	GtkWidget		*widget, *entry, *menu, *combo;
+void on_prefbtn_clicked(void) {
+	GtkWidget		*widget, *entry, *menu;
 	GtkAdjustment		*itemCount;
 	GtkTreeStore		*treestore;
 	GtkTreeViewColumn 	*column;
 	GSList			*list;
-	gchar			*widgetname, *proxyport;
+	gchar			*proxyport;
 	gchar			*configuredBrowser, *name;
-	gboolean		enabled, enabled2;
+	gboolean		enabled;
 	int			tmp, i;
 	static int		manual;
 	struct browser			*iter;
-	struct enclosure_download_tool	*edtool;
 	
 	if (!prefdialog) {
 		prefdialog = liferea_dialog_new (NULL, "prefdialog");
@@ -604,14 +600,14 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 			entry = gtk_menu_item_new_with_label(_(iter->display));
 			gtk_widget_show(entry);
 			gtk_container_add(GTK_CONTAINER(menu), entry);
-			gtk_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(on_browser_changed), GINT_TO_POINTER(i));
+			g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(on_browser_changed), GINT_TO_POINTER(i));
 		}
 		manual = i;
 		/* This allows the user to choose their own browser by typing in the command. */
 		entry = gtk_menu_item_new_with_label(_("Manual"));
 		gtk_widget_show(entry);
 		gtk_container_add(GTK_CONTAINER(menu), entry);
-		gtk_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(on_browser_changed), GINT_TO_POINTER(i));
+		g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(on_browser_changed), GINT_TO_POINTER(i));
 
 		gtk_option_menu_set_menu(GTK_OPTION_MENU(liferea_dialog_lookup(prefdialog, "browserpopup")), menu);
 
@@ -621,35 +617,32 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 		entry = gtk_menu_item_new_with_label(_("Browser default"));
 		gtk_widget_show(entry);
 		gtk_container_add(GTK_CONTAINER(menu), entry);
-		gtk_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(on_browser_place_changed), GINT_TO_POINTER(0));
+		g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(on_browser_place_changed), GINT_TO_POINTER(0));
 
 		entry = gtk_menu_item_new_with_label(_("Existing window"));
 		gtk_widget_show(entry);
 		gtk_container_add(GTK_CONTAINER(menu), entry);
-		gtk_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(on_browser_place_changed), GINT_TO_POINTER(1));
+		g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(on_browser_place_changed), GINT_TO_POINTER(1));
 
 		entry = gtk_menu_item_new_with_label(_("New window"));
 		gtk_widget_show(entry);
 		gtk_container_add(GTK_CONTAINER(menu), entry);
-		gtk_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(on_browser_place_changed), GINT_TO_POINTER(2));
+		g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(on_browser_place_changed), GINT_TO_POINTER(2));
 
 		entry = gtk_menu_item_new_with_label(_("New tab"));
 		gtk_widget_show(entry);
 		gtk_container_add(GTK_CONTAINER(menu), entry);
-		gtk_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(on_browser_place_changed), GINT_TO_POINTER(3));
+		g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(on_browser_place_changed), GINT_TO_POINTER(3));
 
 		gtk_option_menu_set_menu(GTK_OPTION_MENU(liferea_dialog_lookup(prefdialog, "browserlocpopup")), menu);
 
-		/* Create the toolbar style combo */
-		combo = liferea_dialog_lookup(prefdialog, "toolbarcombo");
-
 		/* ================== panel 1 "feeds" ==================== */
 
 		/* menu for feed startup update action */
-		ui_prefs_setup_combo_menu ("startupActionCombo", 
-		                           startup_update_options, 
-		                           G_CALLBACK (on_feed_startup_update_changed),
-		                           conf_get_int_value(STARTUP_FEED_ACTION));
+		ui_common_setup_combo_menu (liferea_dialog_lookup (prefdialog, "startupActionCombo"),
+		                            startup_update_options, 
+		                            G_CALLBACK (on_feed_startup_update_changed),
+		                            conf_get_int_value(STARTUP_FEED_ACTION));
 
 		/* cache size setting */
 		widget = liferea_dialog_lookup (prefdialog, "itemCountBtn");
@@ -657,12 +650,12 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 		gtk_adjustment_set_value (itemCount, conf_get_int_value (DEFAULT_MAX_ITEMS));
 
 		/* set default update interval spin button and unit combo box */
-		ui_prefs_setup_combo_menu ("refreshIntervalUnitComboBox",
-		                           default_update_interval_unit_options,
-		                           G_CALLBACK (on_default_update_interval_unit_changed),
-					   -1);
+		ui_common_setup_combo_menu (liferea_dialog_lookup (prefdialog, "globalRefreshIntervalUnitComboBox"),
+		                            default_update_interval_unit_options,
+		                            G_CALLBACK (on_default_update_interval_unit_changed),
+					    -1);
 					   
-		widget = liferea_dialog_lookup (prefdialog, "refreshIntervalUnitComboBox");
+		widget = liferea_dialog_lookup (prefdialog, "globalRefreshIntervalUnitComboBox");
 		tmp = conf_get_int_value (DEFAULT_UPDATE_INTERVAL);
 		if (tmp % 1440 == 0) {		/* days */
 			gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 2);
@@ -673,7 +666,7 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 		} else {			/* minutes */
 			gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 		}
-		widget = liferea_dialog_lookup (prefdialog,"refreshIntervalSpinButton");
+		widget = liferea_dialog_lookup (prefdialog,"globalRefreshIntervalSpinButton");
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), tmp);
 		g_signal_connect (G_OBJECT (widget), "changed", G_CALLBACK (on_default_update_interval_value_changed), NULL);
 
@@ -685,29 +678,49 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 
 		/* ================== panel 3 "headlines" ==================== */
 
-		ui_prefs_setup_combo_menu ("skimKeyCombo",
-		                           browser_skim_key_options,
-		                           G_CALLBACK (on_skim_key_changed),
-		                           conf_get_int_value (BROWSE_KEY_SETTING));
+		ui_common_setup_combo_menu (liferea_dialog_lookup (prefdialog, "skimKeyCombo"),
+		                            browser_skim_key_options,
+		                            G_CALLBACK (on_skim_key_changed),
+		                            conf_get_int_value (BROWSE_KEY_SETTING));
 					  
 		/* Setup social bookmarking list */
 		i = 0;
-		name = conf_get_str_value(SOCIAL_BM_SITE);
-		menu = gtk_menu_new();
-		list = socialBookmarkSites;
-		while(list) {
-			socialBookmarkSitePtr siter = list->data;
-			if(name && !strcmp(siter->name, name))
+		name = conf_get_str_value (SOCIAL_BM_SITE);
+		menu = gtk_menu_new ();
+		list = bookmarkSites;
+		while (list) {
+			socialSitePtr siter = list->data;
+			if (name && !strcmp (siter->name, name))
 				tmp = i;
-			entry = gtk_menu_item_new_with_label(siter->name);
-			gtk_widget_show(entry);
-			gtk_container_add(GTK_CONTAINER(menu), entry);
-			gtk_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(on_socialsite_changed), (gpointer)siter->name);
-			list = g_slist_next(list);
+			entry = gtk_menu_item_new_with_label (siter->name);
+			gtk_widget_show (entry);
+			gtk_container_add (GTK_CONTAINER (menu), entry);
+			g_signal_connect (G_OBJECT (entry), "activate", G_CALLBACK (on_socialsite_changed), (gpointer)siter->name);
+			list = g_slist_next (list);
 			i++;
 		}
-		gtk_option_menu_set_menu(GTK_OPTION_MENU(liferea_dialog_lookup(prefdialog, "socialpopup")), menu);
-		gtk_option_menu_set_history(GTK_OPTION_MENU(liferea_dialog_lookup(prefdialog, "socialpopup")), tmp);
+		gtk_option_menu_set_menu (GTK_OPTION_MENU (liferea_dialog_lookup (prefdialog, "socialpopup")), menu);
+		gtk_option_menu_set_history (GTK_OPTION_MENU (liferea_dialog_lookup (prefdialog, "socialpopup")), tmp);
+		
+		/* Setup link cosmos search engine list */
+		i = 0;
+		name = conf_get_str_value (SOCIAL_LINK_SEARCH_SITE);
+		menu = gtk_menu_new ();
+		list = linkSearchSites;
+		while (list) {
+			socialSitePtr siter = list->data;
+			if (name && !strcmp (siter->name, name))
+				tmp = i;
+			entry = gtk_menu_item_new_with_label (siter->name);
+			gtk_widget_show (entry);
+			gtk_container_add (GTK_CONTAINER (menu), entry);
+			g_signal_connect (G_OBJECT (entry), "activate", G_CALLBACK (on_linksearchsite_changed), (gpointer)siter->name);
+			list = g_slist_next (list);
+			i++;
+		}
+		gtk_option_menu_set_menu (GTK_OPTION_MENU (liferea_dialog_lookup (prefdialog, "searchpopup")), menu);
+		gtk_option_menu_set_history (GTK_OPTION_MENU (liferea_dialog_lookup (prefdialog, "searchpopup")), tmp);
+		
 
 		/* ================== panel 4 "browser" ==================== */
 
@@ -719,9 +732,9 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 		widget = liferea_dialog_lookup(prefdialog, "disablejavascript");
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), conf_get_bool_value(DISABLE_JAVASCRIPT));
 		
-		/* set the allow Flash flag */
-		widget = liferea_dialog_lookup(prefdialog, "allowflash");
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), conf_get_bool_value(ALLOW_FLASH));
+		/* set the enable Plugins flag */
+		widget = liferea_dialog_lookup(prefdialog, "enableplugins");
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), conf_get_bool_value(ENABLE_PLUGINS));
 
 		tmp = 0;
 		configuredBrowser = conf_get_str_value(BROWSER_ID);
@@ -745,56 +758,45 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 
 		/* ================== panel 4 "GUI" ================ */
 
-		widget = liferea_dialog_lookup(prefdialog, "popupwindowsoptionbtn");
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), conf_get_bool_value(SHOW_POPUP_WINDOWS));
+		widget = liferea_dialog_lookup (prefdialog, "popupwindowsoptionbtn");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), conf_get_bool_value (SHOW_POPUP_WINDOWS));
 		
-		widget = liferea_dialog_lookup(prefdialog, "trayiconoptionbtn");
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), conf_get_bool_value(SHOW_TRAY_ICON));
+		widget = liferea_dialog_lookup (prefdialog, "trayiconoptionbtn");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), conf_get_bool_value (SHOW_TRAY_ICON));
 
-		widget = liferea_dialog_lookup(prefdialog, "newcountintraybtn");
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), conf_get_bool_value(SHOW_NEW_COUNT_IN_TRAY));
-		gtk_widget_set_sensitive(liferea_dialog_lookup(prefdialog, "newcountintraybtn"), conf_get_bool_value(SHOW_TRAY_ICON));
+		widget = liferea_dialog_lookup (prefdialog, "newcountintraybtn");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), conf_get_bool_value (SHOW_NEW_COUNT_IN_TRAY));
+		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "newcountintraybtn"), conf_get_bool_value (SHOW_TRAY_ICON));
 
-		widget = liferea_dialog_lookup(prefdialog, "minimizetotraybtn");
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), conf_get_bool_value(DONT_MINIMIZE_TO_TRAY));
-		gtk_widget_set_sensitive(liferea_dialog_lookup(prefdialog, "minimizetotraybtn"), conf_get_bool_value(SHOW_TRAY_ICON));
+		widget = liferea_dialog_lookup (prefdialog, "minimizetotraybtn");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), conf_get_bool_value (DONT_MINIMIZE_TO_TRAY));
+		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "minimizetotraybtn"), conf_get_bool_value (SHOW_TRAY_ICON));
+		
+		widget = liferea_dialog_lookup (prefdialog, "startintraybtn");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), conf_get_bool_value (START_IN_TRAY));
+		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "startintraybtn"), conf_get_bool_value (SHOW_TRAY_ICON));
 
-		/* menu / tool bar settings */	
-		for(i = 1; i <= 3; i++) {
-			/* Set fields in the radio widgets so that they know their option # and the pref dialog */
-			widgetname = g_strdup_printf("%s%d", "menuradiobtn", i);
-			widget = liferea_dialog_lookup(prefdialog, widgetname);
-			gtk_object_set_data(GTK_OBJECT(widget), "option_number", GINT_TO_POINTER(i));
-			g_free(widgetname);
-		}
-
-		/* select currently active menu option */
-		tmp = 1;
-		if(conf_get_bool_value(DISABLE_TOOLBAR)) tmp = 2;
-		if(conf_get_bool_value(DISABLE_MENUBAR)) tmp = 3;
-
-		widgetname = g_strdup_printf("%s%d", "menuradiobtn", tmp);
-		widget = liferea_dialog_lookup(prefdialog, widgetname);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), TRUE);
-		g_free(widgetname);
+		/* tool bar settings */	
+		widget = liferea_dialog_lookup (prefdialog, "hidetoolbarbtn");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), conf_get_bool_value(DISABLE_TOOLBAR));
 
 		/* select currently active toolbar style option */
-		name = conf_get_str_value(TOOLBAR_STYLE);
+		name = conf_get_str_value (TOOLBAR_STYLE);
 		for (i = 0; gui_toolbar_style_values[i] != NULL; ++i) {
-			if (strcmp(name, gui_toolbar_style_values[i]) == 0)
+			if (strcmp (name, gui_toolbar_style_values[i]) == 0)
 				break;
 		}
 		g_free (name);
 
-		/* Invalid key value. Revert to default */
+		/* On invalid key value: revert to default */
 		if (gui_toolbar_style_values[i] == NULL)
 			i = 0;
 
 		/* create toolbar style menu */
-		ui_prefs_setup_combo_menu ("toolbarCombo",
-		                           gui_toolbar_style_options,
-		                           G_CALLBACK (on_gui_toolbar_style_changed),
-		                           i);
+		ui_common_setup_combo_menu (liferea_dialog_lookup (prefdialog, "toolbarCombo"),
+		                            gui_toolbar_style_options,
+		                            G_CALLBACK (on_gui_toolbar_style_changed),
+		                            i);
 
 		/* ================= panel 5 "proxy" ======================== */
 		proxyport = g_strdup_printf ("%d", conf_get_int_value (PROXY_PORT));
@@ -836,18 +838,18 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 		/* ================= panel 6 "enclosures" ======================== */
 
 		/* menu for download tool */
-		ui_prefs_setup_combo_menu ("downloadToolCombo",
-		                           enclosure_download_tool_options,
-					   G_CALLBACK (on_enclosure_download_tool_changed),
-					   conf_get_int_value (ENCLOSURE_DOWNLOAD_TOOL));
+		ui_common_setup_combo_menu (liferea_dialog_lookup (prefdialog, "downloadToolCombo"),
+		                            enclosure_download_tool_options,
+		                            G_CALLBACK (on_enclosure_download_tool_changed),
+		                            conf_get_int_value (ENCLOSURE_DOWNLOAD_TOOL));
 
 		/* set enclosure download path entry */	
 		gtk_entry_set_text(GTK_ENTRY(liferea_dialog_lookup(prefdialog, "save_download_entry")), conf_get_str_value(ENCLOSURE_DOWNLOAD_PATH));
 
 		/* set up list of configured enclosure types */
 		treestore = gtk_tree_store_new(FTS_LEN, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
-		list = ui_enclosure_get_types();
-		while(NULL != list) {
+		list = (GSList *)enclosure_mime_types_get ();
+		while (list) {
 			GtkTreeIter *newIter = g_new0(GtkTreeIter, 1);
 			gtk_tree_store_append(treestore, newIter, NULL);
 			gtk_tree_store_set(treestore, newIter,
@@ -869,6 +871,14 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 		gtk_tree_view_append_column(GTK_TREE_VIEW(widget), column);
 
 		gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(widget)), GTK_SELECTION_SINGLE);
+
+		/* ================= panel 7 "sync" ======================== */
+
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (prefdialog, "useAvahiSync")), conf_get_bool_value (SYNC_AVAHI_ENABLED));
+		gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (prefdialog, "avahiServiceNameEntry")), conf_get_str_value (SYNC_AVAHI_SERVICE_NAME));		
+		gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (prefdialog, "avahiServicePasswordEntry")), conf_get_str_value (SYNC_AVAHI_PASSWORD));
+		gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog, "avahiServiceNameEntry")), conf_get_bool_value (SYNC_AVAHI_ENABLED));
+		gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog, "avahiServicePasswordEntry")), conf_get_bool_value (SYNC_AVAHI_ENABLED));
 	}	
 	gtk_window_present(GTK_WINDOW(prefdialog));
 }
