@@ -1,7 +1,7 @@
 /**
  * @file xml.c XML helper methods for Liferea
  * 
- * Copyright (C) 2003-2007  Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2009  Lars Lindner <lars.lindner@gmail.com>
  * Copyright (C) 2004-2006  Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -237,45 +237,57 @@ xhtml_is_well_formed (const gchar *data)
 	return result;
 }
 
-gchar *
-xhtml_strip_dhtml (const gchar *html)
-{
-	gchar *tmp;
+static GSList *dhtml_strippers = NULL;
 
-	// FIXME: move to XSLT stylesheet that post processes
-	// generated XHTML. The solution below might break harmless
-	// escaped HTML.
+static void
+xhtml_stripper_add (GSList **strippers, const gchar *pattern)
+{
+	GError *err = NULL;
+	GRegex *expr;
 	
-	/* remove some nasty DHTML stuff from the given HTML content */
-	tmp = g_strdup (html);
-	tmp = common_strreplace (tmp, " onload=", " no_onload=");
-	tmp = common_strreplace (tmp, " onLoad=", " no_onLoad=");
-	tmp = common_strreplace (tmp, "script>", "no_script>");		
-	tmp = common_strreplace (tmp, "<script ", "<no_script ");
-	tmp = common_strreplace (tmp, "<meta ", "<no_meta ");
-	tmp = common_strreplace (tmp, "/meta>", "/no_meta>");
-	tmp = common_strreplace (tmp, "<iframe ", "<no_iframe ");
-	tmp = common_strreplace (tmp, "/iframe>", "/no_iframe>");
+	expr = g_regex_new (pattern, G_REGEX_CASELESS | G_REGEX_UNGREEDY | G_REGEX_DOTALL | G_REGEX_OPTIMIZE, 0, &err);
+	if (err) {
+		g_warning ("xhtml_strip_setup: %s\n", err->message);
+		g_error_free (err);
+	}
+	*strippers = g_slist_append (*strippers, expr);
+}
+
+static gchar *
+xhtml_strip (const gchar *html, GSList *strippers)
+{
+	gchar *result = g_strdup (html);
+	GSList *iter = strippers;
 	
-	return tmp;
+	while (iter) {
+		GError *err = NULL;
+		GRegex *expr = (GRegex *)iter->data;
+		gchar *tmp = result;
+		result = g_regex_replace (expr, tmp, -1, 0, "", 0, &err);
+		if (err) {
+			g_warning ("xhtml_strip: %s\n", err->message);
+			g_error_free (err);
+			err = NULL;
+		}
+		g_free (tmp);
+		iter = g_slist_next (iter);
+	}
+
+	return result;
 }
 
 gchar *
-xhtml_strip_flash (const gchar *html)
+xhtml_strip_dhtml (const gchar *html)
 {
-	gchar *tmp;
+	if (!dhtml_strippers) {
+		xhtml_stripper_add (&dhtml_strippers, "\\s+onload='[^']+'");
+		xhtml_stripper_add (&dhtml_strippers, "\\s+onload=\"[^\"]+\"");
+		xhtml_stripper_add (&dhtml_strippers, "<\\s*script\\s*>.*</\\s*script\\s*>");
+		xhtml_stripper_add (&dhtml_strippers, "<\\s*meta\\s*>.*</\\s*meta\\s*>");
+		xhtml_stripper_add (&dhtml_strippers, "<\\s*iframe[^>]*\\s*>.*</\\s*iframe\\s*>");
+	}
 	
-	// FIXME: move to XSLT stylesheet that post processes
-	// generated XHTML. The solution below might break harmless
-	// escaped HTML.
-	
-	tmp = g_strdup (html);
-	tmp = common_strreplace (tmp, "<object ", "<no_object ");
-	tmp = common_strreplace (tmp, "/object>", "/no_object>");
-	tmp = common_strreplace (tmp, "<embed ", "<no_embed ");
-	tmp = common_strreplace (tmp, "/embed>", "/no_embed>");
-
-	return tmp;
+	return xhtml_strip (html, dhtml_strippers);
 }
 
 typedef struct {
@@ -382,7 +394,7 @@ xml_buffer_parse_error (void *ctxt, const gchar * msg, ...)
 	gchar		*newmsg;
 	gchar		*tmp;
 	
-	if (MAX_PARSE_ERROR_LINES > errors->errorCount++) {		
+	if (MAX_PARSE_ERROR_LINES > errors->errorCount++) {
 		va_start (params, msg);
 		newmsg = g_strdup_vprintf (msg, params);
 		va_end (params);
@@ -404,7 +416,7 @@ xml_buffer_parse_error (void *ctxt, const gchar * msg, ...)
 
 static xmlDocPtr entities = NULL;
 
-xmlEntityPtr
+static xmlEntityPtr
 xml_process_entities (void *ctxt, const xmlChar *name)
 {
 	xmlEntityPtr	entity, found;
@@ -439,7 +451,7 @@ xml_process_entities (void *ctxt, const xmlChar *name)
 }
 
 xmlNodePtr 
-xpath_find (xmlNodePtr node, gchar *expr)
+xpath_find (xmlNodePtr node, const gchar *expr)
 {
 	xmlNodePtr	result = NULL;
 	
@@ -491,6 +503,26 @@ xpath_foreach_match (xmlNodePtr node, gchar *expr, xpathMatchFunc func, gpointer
 	return FALSE;
 }
 
+gchar *
+xml_get_attribute (xmlNodePtr node, const gchar *name)
+{
+	/* For RSS we use libxml2 in recovery mode and we need to
+	   ensure to never get invalid characters, which is why we
+	   use common_utf8_fix() on each result here... */
+	   
+	return common_utf8_fix (xmlGetProp (node, BAD_CAST name));
+}
+
+gchar *
+xml_get_ns_attribute (xmlNodePtr node, const gchar *name, const gchar *namespace)
+{
+	/* For RSS we use libxml2 in recovery mode and we need to
+	   ensure to never get invalid characters, which is why we
+	   use common_utf8_fix() on each result here... */
+	   
+	return common_utf8_fix (xmlGetNsProp (node, BAD_CAST name, BAD_CAST namespace));
+}
+
 xmlDocPtr
 xml_parse (gchar *data, size_t length, gboolean recovery, errorCtxtPtr errCtx)
 {
@@ -539,7 +571,7 @@ xml_parse_feed (feedParserCtxtPtr fpc)
 	
 	fpc->doc = xml_parse (fpc->data, (size_t)fpc->dataLength, fpc->recovery, errors);
 	if (!fpc->doc) {
-		debug1 (DEBUG_PARSING, "xml_parser_feed(): could not parse feed \"%s\"!", fpc->subscription->node->title);
+		debug1 (DEBUG_PARSING, "xml_parse_feed(): could not parse feed \"%s\"!", fpc->subscription->node->title);
 		g_string_prepend (fpc->feed->parseErrors, _("XML Parser: Could not parse document:\n"));
 		g_string_append (fpc->feed->parseErrors, "\n");
 	}
